# DeepClas4Bio

DeepClas4Bio is a project that aims to facilitate the interoperability of bioimaging tools with deep learning frameworks.
In particular, we have developed an extensible API that provides a common access point for classification models of
several deep learning frameworks. This project groups the main deep learning frameworks, namely, Keras, Caffe,
DeepLearning4J, MxNet and PyTorch.

Using DeepClas4Bio, the users could work with the main deep learning frameworks easily and transparently for their.
Even the users can use the pretrained models included in the API for classify an image or they can train their own
models and load it in the API to use it in a simple way.